
# use SysV init for EPEL 5/6
%if 0%{?rhel}%{?fedora} < 7
%define has_systemd 0
%else
%define has_systemd 1
%endif

Name:           ekeyd
Version:        1.1.5
Release:        1%{?dist}
Summary:        Simtec Electronics UDEKEY01 Entropy Key Daemon

Group:          System Environment/Daemons
License:        Copyright 2011 Simtec Electronics
URL:            http://www.simtec.co.uk/products/UDEKEY01/files/
Source0:        http://ftp.de.debian.org/debian/pool/main/e/ekeyd/%{name}_%{version}.orig.tar.gz
Source1:        ekeyd.init
Source2:        ekeyd.service
Source3:        egd-linux.sysconfig
Source4:        egd-linux.init
Source5:        egd-linux@.service
Patch0:         systemd-no-fork.patch
Patch1:         entroopykey-udevrules.patch
BuildRoot:      %{_tmppath}/%{name}-%{version}-%{release}-root-%(%{__id_u} -n)

BuildRequires:  lua, lua-devel, udev
Requires:       lua-socket
%if 0%{?has_systemd}
Requires(post): systemd
Requires(preun): systemd
Requires(postun): systemd
BuildRequires: systemd
BuildRequires: systemd-devel
%else
Requires(post): chkconfig
Requires(preun): chkconfig
Requires(preun): initscripts
Requires(postun): initscripts
%endif

%description
Simtec Electronics UDEKEY01 Entropy Key Daemon
This is a driver for the Simtec Electronics Entropy Key.  It is
only needed if you have such a device (or devices).  It provides
a daemon and tools to drive and control it, as well as options
for injecting entropy directly into the kernel's pool, or serving
it via the EGD protocol.

%package egd-linux
Summary:        EGD to Linux Kernel pool top-up daemon
Group:          System Environment/Daemons

%description egd-linux
EGD (Entropy Gathering Daemon) created a de-facto standard for
the distribution of entropy (random data) over a socket.  This
daemon connects to another daemon which implements the same
protocol as EGD (such as ekeyd) and then injects entropy into
the Linux kernel random pool.

%prep
%setup -q
%if 0%{?has_systemd}
%patch0 -p1
%patch1 -p1
%endif

%build
cd host
# Lua binary has no version on these distros...
make LUA_V='' BUILD_ULUSBD=no

%install
rm -rf $RPM_BUILD_ROOT
# build the main code
cd host
make install BUILD_ULUSBD=no DESTDIR=${RPM_BUILD_ROOT}
cd ..
#Install udev
mkdir -p ${RPM_BUILD_ROOT}/%{_udevrulesdir}
%if 0%{?has_systemd}
cp udev/fedora15/60-entropykey.rules ${RPM_BUILD_ROOT}/%{_udevrulesdir}/90-entropykey.rules
install -D -m 0755 -p %{SOURCE2} $RPM_BUILD_ROOT%{_unitdir}/ekeyd.service
install -D -m 0755 -p %{SOURCE5} $RPM_BUILD_ROOT%{_unitdir}/egd-linux@.service
%else
mkdir -p ${RPM_BUILD_ROOT}/lib/udev
cp udev/entropykey.sh ${RPM_BUILD_ROOT}/lib/udev/entropykey.sh
%if 0%{?rhel} && 0%{?rhel} == 5
cp udev/centos5/entropykey_id.sh ${RPM_BUILD_ROOT}/lib/udev/entropykey_id.sh
cp udev/centos5/60-entropykey.rules ${RPM_BUILD_ROOT}/%{_udevrulesdir}/60-entropykey.rules
%else
cp udev/centos6/60-entropykey.rules ${RPM_BUILD_ROOT}/%{_udevrulesdir}/60-entropykey.rules
%endif
# Put the init script in place
mkdir -p ${RPM_BUILD_ROOT}%{_initrddir}
install -m 755 ${RPM_SOURCE_DIR}/ekeyd.init ${RPM_BUILD_ROOT}%{_initrddir}/ekeyd
install -m 755 ${RPM_SOURCE_DIR}/egd-linux.init ${RPM_BUILD_ROOT}%{_initrddir}/egd-linux
mkdir -p ${RPM_BUILD_ROOT}%{_sysconfdir}/sysconfig
install -m 644 ${RPM_SOURCE_DIR}/egd-linux.sysconfig ${RPM_BUILD_ROOT}%{_sysconfdir}/sysconfig/egd-linux
%endif
%clean
rm -rf ${RPM_BUILD_ROOT}


%files
%defattr(-,root,root,-)
#%doc AUTHORS COPYING NEWS README
%doc doc/README doc/README.security doc/README.protocol doc/README.Centos5
%config(noreplace) %{_sysconfdir}/entropykey/ekeyd.conf
%config(noreplace) %{_sysconfdir}/entropykey/keyring
%{_sbindir}/ekey-rekey
%{_sbindir}/ekey-setkey
%{_sbindir}/ekeyd
%{_sbindir}/ekeydctl
%{_mandir}/man5/ekeyd.conf.5.gz
%{_mandir}/man8/ekey-rekey.8.gz
%{_mandir}/man8/ekey-setkey.8.gz
%{_mandir}/man8/ekeyd.8.gz
%{_mandir}/man8/ekeydctl.8.gz
%if 0%{?has_systemd}
%{_unitdir}/ekeyd.service
%else
%{_initrddir}/ekeyd
%endif
%if 0%{?has_systemd}
%{_udevrulesdir}/90-entropykey.rules
%else
/lib/udev/entropykey*.sh
%{_udevrulesdir}/60-entropykey.rules
%endif
#%exclude %{_datadir}/doc/*

%files egd-linux
%defattr(-,root,root,-)
%doc doc/README.egd-linux doc/README.egd-protocol
%{_sbindir}/egd-linux
%{_mandir}/man8/egd-linux.8.gz
%if 0%{?has_systemd}
%{_unitdir}/egd-linux@.service
%else
%{_initrddir}/egd-linux
%config(noreplace) %{_sysconfdir}/sysconfig/egd-linux
%endif
%post

%if 0%{?has_systemd}
%systemd_post ekeyd.service
%else
/sbin/chkconfig --add ekeyd
%endif

if test -x /sbin/udevcontrol; then
    udevcontrol --reload_rules >/dev/null 2>&1 || udevcontrol reload_rules >/dev/null 2>&1
elif test -x /sbin/udevadm; then
    udevadm control --reload-rules >/dev/null 2>&1 || udevadm control --reload_rules >/dev/null 2>&1
fi

%preun
%if 0%{?has_systemd}
%systemd_preun ekeyd.service
%else
if [ $1 = 0 ] ; then
  /sbin/service ekeyd stop >/dev/null 2>&1
  /sbin/chkconfig --del ekeyd
fi
%endif

%postun
%if 0%{?has_systemd}
%systemd_preun ekeyd.service
%else
if [ "$1" -ge "1" ] ; then
  /sbin/service ekeyd condrestart >/dev/null 2>&1 || :
fi
%endif

if test -x /sbin/udevcontrol; then
    udevcontrol --reload_rules >/dev/null 2>&1 || udevcontrol reload_rules >/dev/null 2>&1
elif test -x /sbin/udevadm; then
    udevadm control --reload-rules >/dev/null 2>&1 || udevadm control --reload_rules >/dev/null 2>&1
fi

%changelog
* Wed Nov 28 2012 Peter Meier <peter.meier@immerda.ch> 1.1.4-2
- Add missing udev script for el5

* Sun Oct 21 2012 Peter Meier <peter.meier@immerda.ch> 1.1.4-2
- Add init.d script for egd-linux and sysconfig file
* Mon Jul 25 2011 Rob Kendrick <rjek@simtec.co.uk> 1.1.4-1
- New upstream release
- Improved udev rules by Vincent Sanders
* Mon Sep 06 2010 Daniel Silverstone <dsilvers@debian.org> 1.1.3-1
- New upstream release
* Tue Nov 17 2009 Daniel Silverstone <dsilvers@debian.org> 1.1.1-1
- New upstream release
* Mon Nov 09 2009 Daniel Silverstone <dsilvers@debian.org> 1.1.0-1
- New upstream release
* Thu Oct 15 2009 Daniel Silverstone <dsilvers@debian.org> 1.0.7-1
- New upstream release
* Tue Sep 15 2009 Daniel Silverstone <dsilvers@debian.org> 1.0.5-1
- New upstream release
* Tue Aug 25 2009 Daniel Silverstone <dsilvers@debian.org> 1.0-1
- Initial upstream release
